@@ -13,7 +13,7 @@ gi.require_version('Gtk', '3.0')
 
 from gi.repository import Gio, GLib, Gtk, Gdk, GdkPixbuf  # noqa: E402
 
-version = '0.0.6'
+version = '0.0.7'
 
 
 @contextlib.contextmanager
@@ -44,13 +44,17 @@ def app_main(mpd_host, mpd_port):
 
     image = Gtk.Image()
     pixbuf = None
+    win_size = None
     win.add(image)
 
     def set_image():
         nonlocal pixbuf
+        nonlocal win_size
 
         if pixbuf:
-            win_width, win_height = win.get_size()
+            win_size = win.get_size()
+            win_width, win_height = win_size
+
             aspect = (pixbuf.get_width() / pixbuf.get_height())
 
             if aspect < 1:
@@ -66,9 +70,9 @@ def app_main(mpd_host, mpd_port):
                     width = (win_height / height) * width
                     height = win_height
 
-            pixbuf = pixbuf.scale_simple(
-                width, height, GdkPixbuf.InterpType.BILINEAR)
-            image.set_from_pixbuf(pixbuf)
+            image.set_from_pixbuf(
+                pixbuf.scale_simple(
+                    width, height, GdkPixbuf.InterpType.BILINEAR))
         else:
             image.clear()
         return False
@@ -93,7 +97,8 @@ def app_main(mpd_host, mpd_port):
     win.show_all()
 
     def _on_resize(*args):
-        set_image()
+        if win.get_size() != win_size:
+            set_image()
 
     win.connect('size-allocate', _on_resize)
 
